# $Id: ca.py 4564 2006-05-21 20:44:42Z wiemann $
# Author: Ivan Vilata i Balaguer <ivan@selidor.net>
# Copyright: This module has been placed in the public domain.

# New language mappings are welcome.  Before doing a new translation, please
# read <http://docutils.sf.net/docs/howto/i18n.html>.  Two files must be
# translated for each language: one in docutils/languages, the other in
# docutils/parsers/rst/languages.

"""
Catalan-language mappings for language-dependent features of Docutils.
"""

__docformat__ = 'reStructuredText'

labels = {
      # fixed: language-dependent
      'author': 'Autor',
      'authors': 'Autors',
      'organization': 'Organitzaci\u00F3',
      'address': 'Adre\u00E7a',
      'contact': 'Contacte',
      'version': 'Versi\u00F3',
      'revision': 'Revisi\u00F3',
      'status': 'Estat',
      'date': 'Data',
      'copyright': 'Copyright',
      'dedication': 'Dedicat\u00F2ria',
      'abstract': 'Resum',
      'attention': 'Atenci\u00F3!',
      'caution': 'Compte!',
      'danger': 'PERILL!',
      'error': 'Error',
      'hint': 'Suggeriment',
      'important': 'Important',
      'note': 'Nota',
      'tip': 'Consell',
      'warning': 'Av\u00EDs',
      'contents': 'Contingut'}
"""Mapping of node class name to label text."""

bibliographic_fields = {
      # language-dependent: fixed
      'autor': 'author',
      'autors': 'authors',
      'organitzaci\u00F3': 'organization',
      'adre\u00E7a': 'address',
      'contacte': 'contact',
      'versi\u00F3': 'version',
      'revisi\u00F3': 'revision',
      'estat': 'status',
      'data': 'date',
      'copyright': 'copyright',
      'dedicat\u00F2ria': 'dedication',
      'resum': 'abstract'}
"""Catalan (lowcased) to canonical name mapping for bibliographic fields."""

author_separators = [';', ',']
"""List of separator strings for the 'Authors' bibliographic field. Tried in
order."""



# -*- coding: utf-8 -*-
# $Id: fa.py 4564 2016-08-10 11:48:42Z
# Author: Shahin <me@5hah.in>
# Copyright: This module has been placed in the public domain.

# New language mappings are welcome.  Before doing a new translation, please
# read <http://docutils.sf.net/docs/howto/i18n.html>.  Two files must be
# translated for each language: one in docutils/languages, the other in
# docutils/parsers/rst/languages.

"""
Persian-language mappings for language-dependent features of
reStructuredText.
"""

__docformat__ = 'reStructuredText'


directives = {
      # language-dependent: fixed
      'توجه': 'attention',
      'احتیاط': 'caution',
      'کد': 'code',
      'بلوک-کد': 'code',
      'کد-منبع': 'code',
      'خطر': 'danger',
      'خطا': 'error',
      'راهنما': 'hint',
      'مهم': 'important',
      'یادداشت': 'note',
      'نکته': 'tip',
      'اخطار': 'warning',
      'تذکر': 'admonition',
      'نوار-کناری': 'sidebar',
      'موضوع': 'topic',
      'بلوک-خط': 'line-block',
      'تلفظ-پردازش-شده': 'parsed-literal',
      'سر-فصل': 'rubric',
      'کتیبه': 'epigraph',
      'نکات-برجسته': 'highlights',
      'نقل-قول': 'pull-quote',
      'ترکیب': 'compound',
      'ظرف': 'container',
      #'questions': u'questions',
      'جدول': 'table',
      'جدول-csv': 'csv-table',
      'جدول-لیست': 'list-table',
      #'qa': u'questions',
      #'faq': u'questions',
      'متا': 'meta',
      'ریاضی': 'math',
      #'imagemap': u'imagemap',
      'تصویر': 'image',
      'شکل': 'figure',
      'شامل': 'include',
      'خام': 'raw',
      'جایگزین': 'replace',
      'یونیکد': 'unicode',
      'تاریخ': 'date',
      'کلاس': 'class',
      'قانون': 'role',
      'قانون-پیش‌فرض': 'default-role',
      'عنوان': 'title',
      'محتوا': 'contents',
      'شماره-فصل': 'sectnum',
      'شماره‌گذاری-فصل': 'sectnum',
      'سرآیند': 'header',
      'پاصفحه': 'footer',
      #'footnotes': u'footnotes',
      #'citations': u'citations',
      'یادداشت-هدف': 'target-notes',
    }
"""Persian name to registered (in directives/__init__.py) directive name
mapping."""

roles = {
    # language-dependent: fixed
    'مخفف': 'abbreviation',
    'سرنام': 'acronym',
    'کد': 'code',
    'شاخص': 'index',
    'زیرنویس': 'subscript',
    'بالانویس': 'superscript',
    'عنوان': 'title-reference',
    'نیرو': 'pep-reference',
    'rfc-reference (translation required)': 'rfc-reference',
    'تاکید': 'emphasis',
    'قوی': 'strong',
    'لفظی': 'literal',
    'ریاضی': 'math',
    'منبع-نام‌گذاری': 'named-reference',
    'منبع-ناشناس': 'anonymous-reference',
    'منبع-پانویس': 'footnote-reference',
    'منبع-نقل‌فول': 'citation-reference',
    'منبع-جایگزینی': 'substitution-reference',
    'هدف': 'target',
    'منبع-uri': 'uri-reference',
    'uri': 'uri-reference',
    'url': 'uri-reference',
    'خام': 'raw',}
"""Mapping of Persian role names to canonical role names for interpreted text.
"""



# $Id: frontmatter.py 8231 2018-11-20 23:55:14Z milde $
# Author: David Goodger, Ueli Schlaepfer <goodger@python.org>
# Copyright: This module has been placed in the public domain.

"""
Transforms related to the front matter of a document or a section
(information found before the main text):

- `DocTitle`: Used to transform a lone top level section's title to
  the document title, promote a remaining lone top-level section's
  title to the document subtitle, and determine the document's title
  metadata (document['title']) based on the document title and/or the
  "title" setting.

- `SectionSubTitle`: Used to transform a lone subsection into a
  subtitle.

- `DocInfo`: Used to transform a bibliographic field list into docinfo
  elements.
"""

__docformat__ = 'reStructuredText'

import re
from docutils import nodes, utils
from docutils.transforms import TransformError, Transform


class TitlePromoter(Transform):

    """
    Abstract base class for DocTitle and SectionSubTitle transforms.
    """

    def promote_title(self, node):
        """
        Transform the following tree::

            <node>
                <section>
                    <title>
                    ...

        into ::

            <node>
                <title>
                ...

        `node` is normally a document.
        """
        # Type check
        if not isinstance(node, nodes.Element):
            raise TypeError('node must be of Element-derived type.')

        # `node` must not have a title yet.
        assert not (len(node) and isinstance(node[0], nodes.title))
        section, index = self.candidate_index(node)
        if index is None:
            return None

        # Transfer the section's attributes to the node:
        # NOTE: Change second parameter to False to NOT replace
        #       attributes that already exist in node with those in
        #       section
        # NOTE: Remove third parameter to NOT copy the 'source'
        #       attribute from section
        node.update_all_atts_concatenating(section, True, True)

        # setup_child is called automatically for all nodes.
        node[:] = (section[:1]        # section title
                   + node[:index]     # everything that was in the
                                      # node before the section
                   + section[1:])     # everything that was in the section
        assert isinstance(node[0], nodes.title)
        return 1

    def promote_subtitle(self, node):
        """
        Transform the following node tree::

            <node>
                <title>
                <section>
                    <title>
                    ...

        into ::

            <node>
                <title>
                <subtitle>
                ...
        """
        # Type check
        if not isinstance(node, nodes.Element):
            raise TypeError('node must be of Element-derived type.')

        subsection, index = self.candidate_index(node)
        if index is None:
            return None
        subtitle = nodes.subtitle()

        # Transfer the subsection's attributes to the new subtitle
        # NOTE: Change second parameter to False to NOT replace
        #       attributes that already exist in node with those in
        #       section
        # NOTE: Remove third parameter to NOT copy the 'source'
        #       attribute from section
        subtitle.update_all_atts_concatenating(subsection, True, True)

        # Transfer the contents of the subsection's title to the
        # subtitle:
        subtitle[:] = subsection[0][:]
        node[:] = (node[:1]       # title
                   + [subtitle]
                   # everything that was before the section:
                   + node[1:index]
                   # everything that was in the subsection:
                   + subsection[1:])
        return 1

    def candidate_index(self, node):
        """
        Find and return the promotion candidate and its index.

        Return (None, None) if no valid candidate was found.
        """
        index = node.first_child_not_matching_class(
            nodes.PreBibliographic)
        if index is None or len(node) > (index + 1) or \
               not isinstance(node[index], nodes.section):
            return None, None
        else:
            return node[index], index


class DocTitle(TitlePromoter):

    """
    In reStructuredText_, there is no way to specify a document title
    and subtitle explicitly. Instead, we can supply the document title
    (and possibly the subtitle as well) implicitly, and use this
    two-step transform to "raise" or "promote" the title(s) (and their
    corresponding section contents) to the document level.

    1. If the document contains a single top-level section as its
       first non-comment element, the top-level section's title
       becomes the document's title, and the top-level section's
       contents become the document's immediate contents. The lone
       top-level section header must be the first non-comment element
       in the document.

       For example, take this input text::

           =================
            Top-Level Title
           =================

           A paragraph.

       Once parsed, it looks like this::

           <document>
               <section names="top-level title">
                   <title>
                       Top-Level Title
                   <paragraph>
                       A paragraph.

       After running the DocTitle transform, we have::

           <document names="top-level title">
               <title>
                   Top-Level Title
               <paragraph>
                   A paragraph.

    2. If step 1 successfully determines the document title, we
       continue by checking for a subtitle.

       If the lone top-level section itself contains a single
       second-level section as its first non-comment element, that
       section's title is promoted to the document's subtitle, and
       that section's contents become the document's immediate
       contents. Given this input text::

           =================
            Top-Level Title
           =================

           Second-Level Title
           ~~~~~~~~~~~~~~~~~~

           A paragraph.

       After parsing and running the Section Promotion transform, the
       result is::

           <document names="top-level title">
               <title>
                   Top-Level Title
               <subtitle names="second-level title">
                   Second-Level Title
               <paragraph>
                   A paragraph.

       (Note that the implicit hyperlink target generated by the
       "Second-Level Title" is preserved on the "subtitle" element
       itself.)

    Any comment elements occurring before the document title or
    subtitle are accumulated and inserted as the first body elements
    after the title(s).

    This transform also sets the document's metadata title
    (document['title']).

    .. _reStructuredText: http://docutils.sf.net/rst.html
    """

    default_priority = 320

    def set_metadata(self):
        """
        Set document['title'] metadata title from the following
        sources, listed in order of priority:

        * Existing document['title'] attribute.
        * "title" setting.
        * Document title node (as promoted by promote_title).
        """
        if not self.document.hasattr('title'):
            if self.document.settings.title is not None:
                self.document['title'] = self.document.settings.title
            elif len(self.document) and isinstance(self.document[0], nodes.title):
                self.document['title'] = self.document[0].astext()

    def apply(self):
        if getattr(self.document.settings, 'doctitle_xform', 1):
            # promote_(sub)title defined in TitlePromoter base class.
            if self.promote_title(self.document):
                # If a title has been promoted, also try to promote a
                # subtitle.
                self.promote_subtitle(self.document)
        # Set document['title'].
        self.set_metadata()


class SectionSubTitle(TitlePromoter):

    """
    This works like document subtitles, but for sections.  For example, ::

        <section>
            <title>
                Title
            <section>
                <title>
                    Subtitle
                ...

    is transformed into ::

        <section>
            <title>
                Title
            <subtitle>
                Subtitle
            ...

    For details refer to the docstring of DocTitle.
    """

    default_priority = 350

    def apply(self):
        if not getattr(self.document.settings, 'sectsubtitle_xform', 1):
            return
        for section in self.document.traverse(nodes.section):
            # On our way through the node tree, we are deleting
            # sections, but we call self.promote_subtitle for those
            # sections nonetheless.  To do: Write a test case which
            # shows the problem and discuss on Docutils-develop.
            self.promote_subtitle(section)


class DocInfo(Transform):

    """
    This transform is specific to the reStructuredText_ markup syntax;
    see "Bibliographic Fields" in the `reStructuredText Markup
    Specification`_ for a high-level description. This transform
    should be run *after* the `DocTitle` transform.

    Given a field list as the first non-comment element after the
    document title and subtitle (if present), registered bibliographic
    field names are transformed to the corresponding DTD elements,
    becoming child elements of the "docinfo" element (except for a
    dedication and/or an abstract, which become "topic" elements after
    "docinfo").

    For example, given this document fragment after parsing::

        <document>
            <title>
                Document Title
            <field_list>
                <field>
                    <field_name>
                        Author
                    <field_body>
                        <paragraph>
                            A. Name
                <field>
                    <field_name>
                        Status
                    <field_body>
                        <paragraph>
                            $RCSfile$
            ...

    After running the bibliographic field list transform, the
    resulting document tree would look like this::

        <document>
            <title>
                Document Title
            <docinfo>
                <author>
                    A. Name
                <status>
                    frontmatter.py
            ...

    The "Status" field contained an expanded RCS keyword, which is
    normally (but optionally) cleaned up by the transform. The sole
    contents of the field body must be a paragraph containing an
    expanded RCS keyword of the form "$keyword: expansion text $". Any
    RCS keyword can be processed in any bibliographic field. The
    dollar signs and leading RCS keyword name are removed. Extra
    processing is done for the following RCS keywords:

    - "RCSfile" expands to the name of the file in the RCS or CVS
      repository, which is the name of the source file with a ",v"
      suffix appended. The transform will remove the ",v" suffix.

    - "Date" expands to the format "YYYY/MM/DD hh:mm:ss" (in the UTC
      time zone). The RCS Keywords transform will extract just the
      date itself and transform it to an ISO 8601 format date, as in
      "2000-12-31".

      (Since the source file for this text is itself stored under CVS,
      we can't show an example of the "Date" RCS keyword because we
      can't prevent any RCS keywords used in this explanation from
      being expanded. Only the "RCSfile" keyword is stable; its
      expansion text changes only if the file name changes.)

    .. _reStructuredText: http://docutils.sf.net/rst.html
    .. _reStructuredText Markup Specification:
       http://docutils.sf.net/docs/ref/rst/restructuredtext.html
    """

    default_priority = 340

    biblio_nodes = {
          'author': nodes.author,
          'authors': nodes.authors,
          'organization': nodes.organization,
          'address': nodes.address,
          'contact': nodes.contact,
          'version': nodes.version,
          'revision': nodes.revision,
          'status': nodes.status,
          'date': nodes.date,
          'copyright': nodes.copyright,
          'dedication': nodes.topic,
          'abstract': nodes.topic}
    """Canonical field name (lowcased) to node class name mapping for
    bibliographic fields (field_list)."""

    def apply(self):
        if not getattr(self.document.settings, 'docinfo_xform', 1):
            return
        document = self.document
        index = document.first_child_not_matching_class(
              nodes.PreBibliographic)
        if index is None:
            return
        candidate = document[index]
        if isinstance(candidate, nodes.field_list):
            biblioindex = document.first_child_not_matching_class(
                  (nodes.Titular, nodes.Decorative))
            nodelist = self.extract_bibliographic(candidate)
            del document[index]         # untransformed field list (candidate)
            document[biblioindex:biblioindex] = nodelist

    def extract_bibliographic(self, field_list):
        docinfo = nodes.docinfo()
        bibliofields = self.language.bibliographic_fields
        labels = self.language.labels
        topics = {'dedication': None, 'abstract': None}
        for field in field_list:
            try:
                name = field[0][0].astext()
                normedname = nodes.fully_normalize_name(name)
                if not (len(field) == 2 and normedname in bibliofields
                        and self.check_empty_biblio_field(field, name)):
                    raise TransformError
                canonical = bibliofields[normedname]
                biblioclass = self.biblio_nodes[canonical]
                if issubclass(biblioclass, nodes.TextElement):
                    if not self.check_compound_biblio_field(field, name):
                        raise TransformError
                    utils.clean_rcs_keywords(
                          field[1][0], self.rcs_keyword_substitutions)
                    docinfo.append(biblioclass('', '', *field[1][0]))
                elif issubclass(biblioclass, nodes.authors):
                    self.extract_authors(field, name, docinfo)
                elif issubclass(biblioclass, nodes.topic):
                    if topics[canonical]:
                        field[-1] += self.document.reporter.warning(
                            'There can only be one "%s" field.' % name,
                            base_node=field)
                        raise TransformError
                    title = nodes.title(name, labels[canonical])
                    title[0].rawsource =  labels[canonical]
                    topics[canonical] = biblioclass(
                        '', title, classes=[canonical], *field[1].children)
                else:
                    docinfo.append(biblioclass('', *field[1].children))
            except TransformError:
                if len(field[-1]) == 1 \
                       and isinstance(field[-1][0], nodes.paragraph):
                    utils.clean_rcs_keywords(
                        field[-1][0], self.rcs_keyword_substitutions)
                # if normedname not in bibliofields:
                classvalue = nodes.make_id(normedname)
                if classvalue:
                    field['classes'].append(classvalue)
                docinfo.append(field)
        nodelist = []
        if len(docinfo) != 0:
            nodelist.append(docinfo)
        for name in ('dedication', 'abstract'):
            if topics[name]:
                nodelist.append(topics[name])
        return nodelist

    def check_empty_biblio_field(self, field, name):
        if len(field[-1]) < 1:
            field[-1] += self.document.reporter.warning(
                  'Cannot extract empty bibliographic field "%s".' % name,
                  base_node=field)
            return None
        return 1

    def check_compound_biblio_field(self, field, name):
        if len(field[-1]) > 1:
            field[-1] += self.document.reporter.warning(
                  'Cannot extract compound bibliographic field "%s".' % name,
                  base_node=field)
            return None
        if not isinstance(field[-1][0], nodes.paragraph):
            field[-1] += self.document.reporter.warning(
                  'Cannot extract bibliographic field "%s" containing '
                  'anything other than a single paragraph.' % name,
                  base_node=field)
            return None
        return 1

    rcs_keyword_substitutions = [
          (re.compile(r'\$' r'Date: (\d\d\d\d)[-/](\d\d)[-/](\d\d)[ T][\d:]+'
                      r'[^$]* \$', re.IGNORECASE), r'\1-\2-\3'),
          (re.compile(r'\$' r'RCSfile: (.+),v \$', re.IGNORECASE), r'\1'),
          (re.compile(r'\$[a-zA-Z]+: (.+) \$'), r'\1'),]

    def extract_authors(self, field, name, docinfo):
        try:
            if len(field[1]) == 1:
                if isinstance(field[1][0], nodes.paragraph):
                    authors = self.authors_from_one_paragraph(field)
                elif isinstance(field[1][0], nodes.bullet_list):
                    authors = self.authors_from_bullet_list(field)
                else:
                    raise TransformError
            else:
                authors = self.authors_from_paragraphs(field)
            authornodes = [nodes.author('', '', *author)
                           for author in authors if author]
            if len(authornodes) >= 1:
                docinfo.append(nodes.authors('', *authornodes))
            else:
                raise TransformError
        except TransformError:
            field[-1] += self.document.reporter.warning(
                  'Bibliographic field "%s" incompatible with extraction: '
                  'it must contain either a single paragraph (with authors '
                  'separated by one of "%s"), multiple paragraphs (one per '
                  'author), or a bullet list with one paragraph (one author) '
                  'per item.'
                  % (name, ''.join(self.language.author_separators)),
                  base_node=field)
            raise

    def authors_from_one_paragraph(self, field):
        """Return list of Text nodes for ";"- or ","-separated authornames."""
        # @@ keep original formatting? (e.g. ``:authors: A. Test, *et-al*``)
        text = ''.join(str(node)
                       for node in field[1].traverse(nodes.Text))
        if not text:
            raise TransformError
        for authorsep in self.language.author_separators:
            # don't split at escaped `authorsep`:
            pattern = '(?<!\x00)%s' % authorsep
            authornames = re.split(pattern, text)
            if len(authornames) > 1:
                break
        authornames = (name.strip() for name in authornames)
        authors = [[nodes.Text(name, utils.unescape(name, True))]
                   for name in authornames if name]
        return authors

    def authors_from_bullet_list(self, field):
        authors = []
        for item in field[1][0]:
            if isinstance(item, nodes.comment):
                continue
            if len(item) != 1 or not isinstance(item[0], nodes.paragraph):
                raise TransformError
            authors.append(item[0].children)
        if not authors:
            raise TransformError
        return authors

    def authors_from_paragraphs(self, field):
        for item in field[1]:
            if not isinstance(item, (nodes.paragraph, nodes.comment)):
                raise TransformError
        authors = [item.children for item in field[1]
                   if not isinstance(item, nodes.comment)]
        return authors



# -*- coding: utf-8 -*-
# $Id: ja.py 4564 2006-05-21 20:44:42Z wiemann $
# Author: Hisashi Morita <hisashim@kt.rim.or.jp>
# Copyright: This module has been placed in the public domain.

# New language mappings are welcome.  Before doing a new translation, please
# read <http://docutils.sf.net/docs/howto/i18n.html>.  Two files must be
# translated for each language: one in docutils/languages, the other in
# docutils/parsers/rst/languages.

"""
Japanese-language mappings for language-dependent features of Docutils.
"""

__docformat__ = 'reStructuredText'

labels = {
      # fixed: language-dependent
      'author': '著者',
      'authors': '著者',
      'organization': '組織',
      'address': '住所',
      'contact': '連絡先',
      'version': 'バージョン',
      'revision': 'リビジョン',
      'status': 'ステータス',
      'date': '日付',
      'copyright': '著作権',
      'dedication': '献辞',
      'abstract': '概要',
      'attention': '注目!',
      'caution': '注意!',
      'danger': '!危険!',
      'error': 'エラー',
      'hint': 'ヒント',
      'important': '重要',
      'note': '備考',
      'tip': '通報',
      'warning': '警告',
      'contents': '目次'}
"""Mapping of node class name to label text."""

bibliographic_fields = {
      # language-dependent: fixed
      '著者': 'author',
      ' n/a': 'authors',
      '組織': 'organization',
      '住所': 'address',
      '連絡先': 'contact',
      'バージョン': 'version',
      'リビジョン': 'revision',
      'ステータス': 'status',
      '日付': 'date',
      '著作権': 'copyright',
      '献辞': 'dedication',
      '概要': 'abstract'}
"""Japanese (lowcased) to canonical name mapping for bibliographic fields."""

author_separators = [';', ',']
"""List of separator strings for the 'Authors' bibliographic field. Tried in
order."""



# $Id: ca.py 7119 2011-09-02 13:00:23Z milde $
# Author: Ivan Vilata i Balaguer <ivan@selidor.net>
# Copyright: This module has been placed in the public domain.

# New language mappings are welcome.  Before doing a new translation, please
# read <http://docutils.sf.net/docs/howto/i18n.html>.  Two files must be
# translated for each language: one in docutils/languages, the other in
# docutils/parsers/rst/languages.

"""
Catalan-language mappings for language-dependent features of
reStructuredText.
"""

__docformat__ = 'reStructuredText'


directives = {
      # language-dependent: fixed
      'atenci\u00F3': 'attention',
      'compte': 'caution',
      'code (translation required)': 'code',
      'perill': 'danger',
      'error': 'error',
      'suggeriment': 'hint',
      'important': 'important',
      'nota': 'note',
      'consell': 'tip',
      'av\u00EDs': 'warning',
      'advertiment': 'admonition',
      'nota-al-marge': 'sidebar',
      'nota-marge': 'sidebar',
      'tema': 'topic',
      'bloc-de-l\u00EDnies': 'line-block',
      'bloc-l\u00EDnies': 'line-block',
      'literal-analitzat': 'parsed-literal',
      'r\u00FAbrica': 'rubric',
      'ep\u00EDgraf': 'epigraph',
      'sumari': 'highlights',
      'cita-destacada': 'pull-quote',
      'compost': 'compound',
      'container (translation required)': 'container',
      #'questions': 'questions',
      'taula': 'table',
      'taula-csv': 'csv-table',
      'taula-llista': 'list-table',
      #'qa': 'questions',
      #'faq': 'questions',
      'math (translation required)': 'math',
      'meta': 'meta',
      #'imagemap': 'imagemap',
      'imatge': 'image',
      'figura': 'figure',
      'inclou': 'include',
      'incloure': 'include',
      'cru': 'raw',
      'reempla\u00E7a': 'replace',
      'reempla\u00E7ar': 'replace',
      'unicode': 'unicode',
      'data': 'date',
      'classe': 'class',
      'rol': 'role',
      'default-role (translation required)': 'default-role',
      'title (translation required)': 'title',
      'contingut': 'contents',
      'numsec': 'sectnum',
      'numeraci\u00F3-de-seccions': 'sectnum',
      'numeraci\u00F3-seccions': 'sectnum',
      'cap\u00E7alera': 'header',
      'peu-de-p\u00E0gina': 'footer',
      'peu-p\u00E0gina': 'footer',
      #'footnotes': 'footnotes',
      #'citations': 'citations',
      'notes-amb-destinacions': 'target-notes',
      'notes-destinacions': 'target-notes',
      'directiva-de-prova-de-restructuredtext': 'restructuredtext-test-directive'}
"""Catalan name to registered (in directives/__init__.py) directive name
mapping."""

roles = {
    # language-dependent: fixed
    'abreviatura': 'abbreviation',
    'abreviaci\u00F3': 'abbreviation',
    'abrev': 'abbreviation',
    'ab': 'abbreviation',
    'acr\u00F2nim': 'acronym',
    'ac': 'acronym',
    'code (translation required)': 'code',
    '\u00EDndex': 'index',
    'i': 'index',
    'sub\u00EDndex': 'subscript',
    'sub': 'subscript',
    'super\u00EDndex': 'superscript',
    'sup': 'superscript',
    'refer\u00E8ncia-a-t\u00EDtol': 'title-reference',
    'refer\u00E8ncia-t\u00EDtol': 'title-reference',
    't\u00EDtol': 'title-reference',
    't': 'title-reference',
    'refer\u00E8ncia-a-pep': 'pep-reference',
    'refer\u00E8ncia-pep': 'pep-reference',
    'pep': 'pep-reference',
    'refer\u00E8ncia-a-rfc': 'rfc-reference',
    'refer\u00E8ncia-rfc': 'rfc-reference',
    'rfc': 'rfc-reference',
    '\u00E8mfasi': 'emphasis',
    'destacat': 'strong',
    'literal': 'literal',
    'math (translation required)': 'math',
    'refer\u00E8ncia-amb-nom': 'named-reference',
    'refer\u00E8ncia-nom': 'named-reference',
    'refer\u00E8ncia-an\u00F2nima': 'anonymous-reference',
    'refer\u00E8ncia-a-nota-al-peu': 'footnote-reference',
    'refer\u00E8ncia-nota-al-peu': 'footnote-reference',
    'refer\u00E8ncia-a-cita': 'citation-reference',
    'refer\u00E8ncia-cita': 'citation-reference',
    'refer\u00E8ncia-a-substituci\u00F3': 'substitution-reference',
    'refer\u00E8ncia-substituci\u00F3': 'substitution-reference',
    'destinaci\u00F3': 'target',
    'refer\u00E8ncia-a-uri': 'uri-reference',
    'refer\u00E8ncia-uri': 'uri-reference',
    'uri': 'uri-reference',
    'url': 'uri-reference',
    'cru': 'raw',}
"""Mapping of Catalan role names to canonical role names for interpreted text.
"""



# -*- coding: utf-8 -*-
# $Id: lv.py 7975 2016-10-20 20:00:19Z milde $
# Copyright: This module has been placed in the public domain.

# New language mappings are welcome.  Before doing a new translation, please
# read <http://docutils.sf.net/docs/howto/i18n.html>.  Two files must be
# translated for each language: one in docutils/languages, the other in
# docutils/parsers/rst/languages.

"""
Latvian-language mappings for language-dependent features of
reStructuredText.
"""

__docformat__ = 'reStructuredText'


directives = {
      # language-dependent: fixed
      'uzmanību': 'attention',
      'piesardzību': 'caution',
      'kods': 'code',
      'koda-bloks': 'code',
      'pirmkods': 'code',
      'bīstami': 'danger',
      'kļūda': 'error',
      'ieteikums': 'hint',
      'svarīgi': 'important',
      'piezīme': 'note',
      'padoms': 'tip',
      'brīdinājums': 'warning',
      'aizrādījums': 'admonition',
      'sānjosla': 'sidebar',
      'tēma': 'topic',
      'rindu-bloks': 'line-block',
      'parsēts-literālis': 'parsed-literal',
      'rubrika': 'rubric',
      'epigrāfs': 'epigraph',
      'apskats': 'highlights',
      'izvilkuma-citāts': 'pull-quote',
      'savienojums': 'compound',
      'konteiners': 'container',
      #'questions': 'questions',
      'tabula': 'table',
      'csv-tabula': 'csv-table',
      'sarakstveida-tabula': 'list-table',
      #'qa': 'questions',
      #'faq': 'questions',
      'meta': 'meta',
      'matemātika': 'math',
      #'imagemap': 'imagemap',
      'attēls': 'image',
      'figūra': 'figure',
      'ietvert': 'include',
      'burtiski': 'raw',
      'aizvieto': 'replace',
      'unicode': 'unicode',
      'datums': 'date',
      'klase': 'class',
      'role': 'role',
      'noklusējuma-role': 'default-role',
      'virsraksts': 'title',
      'saturs': 'contents',
      'numurēt-sekcijas': 'sectnum',
      'galvene': 'header',
      'kājene': 'footer',
      #'footnotes': 'footnotes',
      #'citations': 'citations',
      'atsauces-apakšā': 'target-notes',
      'restructuredtext-testa-direktīva': 'restructuredtext-test-directive'}
"""English name to registered (in directives/__init__.py) directive name
mapping."""

roles = {
    # language-dependent: fixed
    'saīsinājums': 'abbreviation',
    'īsi': 'abbreviation',
    'akronīms': 'acronym',
    'kods': 'code',
    'indekss': 'index',
    'i': 'index',
    'apakšraksts': 'subscript',
    'apakšā': 'subscript',
    'augšraksts': 'superscript',
    'augšā': 'superscript',
    'virsraksta-atsauce': 'title-reference',
    'virsraksts': 'title-reference',
    'v': 'title-reference',
    'atsauce-uz-pep': 'pep-reference',
    'pep': 'pep-reference',
    'atsauce-uz-rfc': 'rfc-reference',
    'rfc': 'rfc-reference',
    'izcēlums': 'emphasis',
    'blīvs': 'strong',
    'literālis': 'literal',
    'matemātika': 'math',
    'nosaukta-atsauce': 'named-reference',
    'nenosaukta-atsauce': 'anonymous-reference',
    'kājenes-atsauce': 'footnote-reference',
    'citātā-atsauce': 'citation-reference',
    'aizvietojuma-atsauce': 'substitution-reference',
    'mēr''kis': 'target',
    'atsauce-uz-uri': 'uri-reference',
    'uri': 'uri-reference',
    'url': 'uri-reference',
    'burtiski': 'raw',}
"""Mapping of English role names to canonical role names for interpreted text.
"""
